@@ -6,6 +6,7 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 */
 // Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package dbconnector
 
@@ -19,7 +20,8 @@ import (
 
 var deletedEdgeCount int
 
-// Recursive helper for DeleteEdge. Takes a single chunk, and recursively attempts to delete that chunk, then the first // and second halves of that chunk independently, and so on.
+// Recursive helper for DeleteEdge. Takes a single chunk, and recursively attempts to delete that chunk, then the first
+// and second halves of that chunk independently, and so on.
 func chunkedDeleteEdgeHelper(resources []Edge) ChunkedOperationResult {
 	if len(resources) == 0 {
 		return ChunkedOperationResult{} // No errors, and no SuccessfulResources
@@ -109,7 +111,7 @@ func deleteEdgeQuery(edges []Edge) string {
 	}
 
 	matchStrings := []string{}  // Build the MATCH portion
-	deleteStrings := []string{} // Build the DELETE portion. Declare this at the same time so that we can do this in one pass.
+	deleteStrings := []string{} // Build the DELETE portion. Declared at the same time so that we do this in one pass.
 	for i, edge := range edges {
 		// e.g. MATCH (s {_uid: 'abc'})-[e:Type]->(d {_uid: 'def'})
 		if edge.SourceKind != "" && edge.DestKind != "" {
